@@ -6,7 +6,7 @@ ifile <- system.file("extdata", "S2008001.L3m_DAY_CHL_chlor_a_9km.nc", package =
 con <- NetCDF(ifile)
 test_that("File exists and can be read", {
   expect_true(file.exists(ifile))
-  expect_that(con, is_a("NetCDF"))
+  expect_that(con, is_a("ncdump"))
   expect_that(vars(con), is_a("tbl_df"))
   expect_that(atts(con), is_a("tbl_df"))
   expect_that(dims(con), is_a("tbl_df"))
